@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from Acquisition import aq_inner
 from plone.autoform.form import AutoExtensibleForm
 from plone.schemaeditor import _
@@ -27,25 +26,21 @@ from zope.schema.interfaces import IField
 from zope.security.interfaces import ForbiddenAttribute
 
 
-import six
-
-
 _marker = object()
 
 
 class IFieldTitle(Interface):
     title = schema.TextLine(
-        title=schema.interfaces.ITextLine['title'].title,
-        description=schema.interfaces.ITextLine['title'].description,
-        default=u'',
+        title=schema.interfaces.ITextLine["title"].title,
+        description=schema.interfaces.ITextLine["title"].description,
+        default="",
         required=True,
     )
 
 
 @implementer(IFieldTitle)
 @adapter(IField)
-class FieldTitleAdapter(object):
-
+class FieldTitleAdapter:
     def __init__(self, field):
         self.field = field
 
@@ -54,6 +49,7 @@ class FieldTitleAdapter(object):
 
     def _write_title(self, value):
         self.field.title = value
+
     title = property(_read_title, _write_title)
 
 
@@ -62,7 +58,6 @@ class IFieldProxy(Interface):
 
 
 class FieldProxySpecification(ObjectSpecificationDescriptor):
-
     def __get__(self, inst, cls=None):
         if inst is None:
             return getObjectSpecification(cls)
@@ -71,42 +66,44 @@ class FieldProxySpecification(ObjectSpecificationDescriptor):
 
 
 @implementer(IFieldProxy)
-class FieldProxy(object):
+class FieldProxy:
 
     __providedBy__ = FieldProxySpecification()
 
     def __init__(self, context):
-        self.__class__ = type(context.__class__.__name__,
-                              (self.__class__, context.__class__), {})
+        self.__class__ = type(
+            context.__class__.__name__, (self.__class__, context.__class__), {}
+        )
         self.__dict__ = context.__dict__
 
 
 @implementer(IDataManager)
 @adapter(IFieldProxy, IField)
 class FieldDataManager(AttributeField):
-
     def get(self):
-        value = super(FieldDataManager, self).get()
+        value = super().get()
         if isinstance(value, Message) and value.default:
             return value.default
         return value
 
     def set(self, value):
         try:
-            old_value = super(FieldDataManager, self).get()
+            old_value = super().get()
         except (AttributeError, ForbiddenAttribute):
             old_value = None
         if isinstance(old_value, Message):
-            value = Message(six.text_type(old_value),
-                            domain=old_value.domain,
-                            default=value,
-                            mapping=old_value.mapping)
-        super(FieldDataManager, self).set(value)
+            value = Message(
+                str(old_value),
+                domain=old_value.domain,
+                default=value,
+                mapping=old_value.mapping,
+            )
+        super().set(value)
 
 
 @implementer(IFieldEditForm)
 class FieldEditForm(AutoExtensibleForm, form.EditForm):
-    id = 'edit-field-form'
+    id = "edit-field-form"
 
     def __init__(self, context, request):
         super(form.EditForm, self).__init__(context, request)
@@ -126,13 +123,18 @@ class FieldEditForm(AutoExtensibleForm, form.EditForm):
     @lazy_property
     def additionalSchemata(self):
         schema_context = self.context.__parent__
-        return [v for k, v in getAdapters((schema_context, self.field),
-                                          interfaces.IFieldEditorExtender)]
+        return [
+            v
+            for k, v in getAdapters(
+                (schema_context, self.field), interfaces.IFieldEditorExtender
+            )
+        ]
 
     @lazy_property
     def label(self):
-        return _(u"Edit Field '${fieldname}'",
-                 mapping={'fieldname': self.field.__name__})
+        return _(
+            "Edit Field '${fieldname}'", mapping={"fieldname": self.field.__name__}
+        )
 
     def updateFields(self):
         # use a custom 'title' field to make sure it is required
@@ -140,12 +142,18 @@ class FieldEditForm(AutoExtensibleForm, form.EditForm):
 
         # omit the order attribute since it's managed elsewhere
         fields += field.Fields(self._schema).omit(
-            'order', 'title', 'default', 'missing_value', 'readonly')
+            "order", "title", "default", "missing_value", "readonly"
+        )
         self.fields = fields
 
+        if "required" in self.fields:
+            # XXX somehow the `required` BooleanField is required which
+            # should not be
+            self.fields["required"].field.required = False
+
         self.updateFieldsFromSchemata()
 
-    @button.buttonAndHandler(_(u'Save'), name='save')
+    @button.buttonAndHandler(_("Save"), name="save")
     def handleSave(self, action):
         data, errors = self.extractData()
         if errors:
@@ -153,36 +161,35 @@ class FieldEditForm(AutoExtensibleForm, form.EditForm):
             return
 
         # clear current min/max to avoid range errors
-        if 'min' in data:
+        if "min" in data:
             self.field.min = None
-        if 'max' in data:
+        if "max" in data:
             self.field.max = None
 
         changes = self.applyChanges(data)
 
         if changes:
             IStatusMessage(self.request).addStatusMessage(
-                self.successMessage, type='info')
+                self.successMessage, type="info"
+            )
         else:
             IStatusMessage(self.request).addStatusMessage(
-                self.noChangesMessage, type='info')
+                self.noChangesMessage, type="info"
+            )
 
         notify(SchemaModifiedEvent(self.context.__parent__))
 
-    @button.buttonAndHandler(_(u'Cancel'), name='cancel')
+    @button.buttonAndHandler(_("Cancel"), name="cancel")
     def handleCancel(self, action):
         self.redirectToParent()
 
     def redirectToParent(self):
         parent = aq_inner(self.context).__parent__
         url = parent.absolute_url()
-        if hasattr(parent, 'schemaEditorView') and parent.schemaEditorView:
-            url += '/@@' + parent.schemaEditorView
+        if hasattr(parent, "schemaEditorView") and parent.schemaEditorView:
+            url += "/@@" + parent.schemaEditorView
 
         self.request.response.redirect(url)
 
 
-EditView = wrap_form(
-    FieldEditForm,
-    index=ViewPageTemplateFile('edit.pt')
-)
+EditView = wrap_form(FieldEditForm, index=ViewPageTemplateFile("edit.pt"))
