@@ -1,17 +1,17 @@
-# -*- coding: utf-8 -*-
 from OFS.interfaces import IItem
 from plone.schemaeditor import _
 from z3c.form.interfaces import IEditForm
-from zope.interface.interfaces import IObjectEvent
 from zope.interface import Invalid
 from zope.interface import invariant
 from zope.interface.interfaces import Attribute
 from zope.interface.interfaces import IInterface
 from zope.interface.interfaces import Interface
+from zope.interface.interfaces import IObjectEvent
 from zope.publisher.interfaces.browser import IBrowserPage
 from zope.schema import ASCIILine
 from zope.schema import Bool
 from zope.schema import Choice
+from zope.schema import Int
 from zope.schema import Object
 from zope.schema import Text
 from zope.schema import TextLine
@@ -21,89 +21,76 @@ import re
 
 
 class ISchemaView(IBrowserPage):
-    """ A publishable view of a zope 3 schema
-    """
+    """A publishable view of a zope 3 schema"""
 
 
 class ISchemaContext(IItem):
-    """ A publishable wrapper of a zope 3 schema
-    """
+    """A publishable wrapper of a zope 3 schema"""
 
-    schema = Object(
-        schema=IInterface
-    )
+    schema = Object(schema=IInterface)
 
-    schemaEditorView = Attribute(
-        """Name of the schema editor view. Optional.""")
+    schemaEditorView = Attribute("""Name of the schema editor view. Optional.""")
 
-    additionalSchemata = Attribute(
-        """Additional schemas that may modify this one.""")
+    additionalSchemata = Attribute("""Additional schemas that may modify this one.""")
 
     allowedFields = Attribute(
         """List of field factory ids that may be added to this schema.
         Or None to allow all fields.
-        """)
+        """
+    )
 
     fieldsWhichCannotBeDeleted = Attribute(
         """List of field names that may not be deleted from this schema."""
     )
 
-    enableFieldsets = Attribute(
-        """Enable extra fieldsets."""
-    )
+    enableFieldsets = Attribute("""Enable extra fieldsets.""")
 
 
 class ISchemaModifiedEvent(IObjectEvent):
 
-    object = Object(
-        schema=ISchemaContext
-    )
+    object = Object(schema=ISchemaContext)
 
 
 class IFieldContext(IItem):
-    """ A publishable wrapper of a zope 3 schema field
-    """
+    """A publishable wrapper of a zope 3 schema field"""
 
-    field = Object(
-        schema=IField
-    )
+    field = Object(schema=IField)
 
 
 class IFieldEditorExtender(IInterface):
-    """ An additional schema for use when editing a field."""
+    """An additional schema for use when editing a field."""
 
 
 class IFieldFactory(IField):
-    """ A component that instantiates a field when called."""
-    title = TextLine(title=u'Title')
+    """A component that instantiates a field when called."""
+
+    title = TextLine(title="Title")
 
     def available(self):
-        """ field is addable in the current context """
+        """field is addable in the current context"""
 
     def editable(self, field):
-        """ test whether a given instance of a field is editable """
+        """test whether a given instance of a field is editable"""
 
     def protected(self, field):
-        """ test whether a given instance of a field is protected """
+        """test whether a given instance of a field is protected"""
 
 
 class IEditableSchema(Interface):
-    """ Interface for adding/removing fields to/from a schema.
-    """
+    """Interface for adding/removing fields to/from a schema."""
 
     def addField(field, name=None):
-        """ Add a field to a schema
+        """Add a field to a schema
 
         If not provided, the field's name will be taken from its __name__
         attribute.
         """
 
     def removeField(field_name):
-        """ Remove a field from a schema
-        """
+        """Remove a field from a schema"""
 
     def moveField(field_name, new_pos):
-        """ Move a field to the (new_pos)th position in the schema's sort ç
+        """Move a field to the (new_pos)th position in the schema's sort ç
         order (indexed beginning at 0).
 
         Schema fields are assigned an 'order' attribute that increments for
@@ -119,65 +106,67 @@ class IEditableSchema(Interface):
 
 
 class IFieldEditForm(IEditForm):
-    """ Marker interface for field edit forms
-    """
+    """Marker interface for field edit forms"""
 
 
 class IFieldEditFormSchema(Interface):
-    """ The schema describing the form fields for a field.
-    """
+    """The schema describing the form fields for a field."""
 
 
 RESERVED_NAMES = (
-    'subject',
-    'format',
-    'language',
-    'creators',
-    'contributors',
-    'rights',
-    'effective_date',
-    'expiration_date',
+    "subject",
+    "format",
+    "language",
+    "creators",
+    "contributors",
+    "rights",
+    "effective_date",
+    "expiration_date",
 )
 
 # a letter followed by letters, numbers, or underscore
-ID_RE = re.compile(r'^[a-z][\w\d\.]*$')
+ID_RE = re.compile(r"^[a-z][\w\d\.]*$")
 
 
 def isValidFieldName(value):
     if not ID_RE.match(value):
         raise Invalid(
-            _(u'Please use only letters, numbers and the following '
-              u'characters: _.')
+            _(
+                "Please start with a lowercase letter and after this use only letters, "
+                "numbers and the following characters: _."
+            )
         )
     if value in RESERVED_NAMES:
-        raise Invalid(
-            _(u"'${name}' is a reserved field name.", mapping={'name': value}))
+        raise Invalid(_("'${name}' is a reserved field name.", mapping={"name": value}))
     return True
 
 
 class INewField(Interface):
 
-    title = TextLine(
-        title=_(u'Title'),
-        required=True
+    fieldset_id = Int(
+        title=_("Fieldset ID"),
+        description=_("Used to decide where to put this field."),
+        required=True,
     )
 
+    title = TextLine(title=_("Title"), required=True)
+
     __name__ = ASCIILine(
-        title=_(u'Short Name'),
-        description=_(u'Used for programmatic access to the field.'),
+        title=_("Short Name"),
+        description=_("Used for programmatic access to the field."),
         required=True,
         constraint=isValidFieldName,
     )
 
     description = Text(
-        title=_(u'Help Text'),
-        description=_(u'Shows up in the form as help text for the field.'),
-        required=False
+        title=_("Help Text"),
+        description=_("Shows up in the form as help text for the field."),
+        required=False,
     )
 
     factory = Choice(
-        title=_(u'Field type'),
-        vocabulary='Fields',
+        title=_("Field type"),
+        vocabulary="Fields",
         required=True,
         # This can't be done yet or we'll create circular import problem.
         # So it will be injected from fields.py
@@ -185,10 +174,8 @@ class INewField(Interface):
     )
 
     required = Bool(
-        title=_(u'Required field'),
-        description=_(
-            u'Check this box if you want this field to be required.'
-        ),
+        title=_("Required field"),
+        description=_("Check this box if you want this field to be required."),
         default=False,
         required=False,
     )
@@ -196,33 +183,23 @@ class INewField(Interface):
     @invariant
     def checkTitleAndDescriptionTypes(data):
         if data.__name__ is not None and data.factory is not None:
-            if data.__name__ == 'title' and \
-                    data.factory.fieldcls is not TextLine:
+            if data.__name__ == "title" and data.factory.fieldcls is not TextLine:
                 raise Invalid(
-                    _(u"The 'title' field must be a Text line (string) field.")
-                )
-            if data.__name__ == 'description' and \
-                    data.factory.fieldcls is not Text:
-                raise Invalid(
-                    _(u"The 'description' field must be a Text field.")
+                    _("The 'title' field must be a Text line (string) field.")
                 )
+            if data.__name__ == "description" and data.factory.fieldcls is not Text:
+                raise Invalid(_("The 'description' field must be a Text field."))
 
 
 class INewFieldset(Interface):
 
-    label = TextLine(
-        title=_(u'Title'),
-        required=True
-    )
+    label = TextLine(title=_("Title"), required=True)
 
     __name__ = ASCIILine(
-        title=_(u'Short Name'),
-        description=_(u'Used for programmatic access to the fieldset.'),
+        title=_("Short Name"),
+        description=_("Used for programmatic access to the fieldset."),
         required=True,
         constraint=isValidFieldName,
     )
 
-    description = Text(
-        title=_(u'Description'),
-        required=False
-    )
+    description = Text(title=_("Description"), required=False)
